# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-16 09:12
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='option',
            options={'ordering': ['number']},
        ),
        migrations.AlterModelOptions(
            name='part',
            options={'ordering': ['number'], 'verbose_name': '\u5c0f\u8282'},
        ),
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ['number']},
        ),
        migrations.AlterModelOptions(
            name='section',
            options={'ordering': ['number'], 'verbose_name': 'course\u8bfe\u4ef6'},
        ),
        migrations.AlterModelOptions(
            name='video',
            options={'ordering': ['number']},
        ),
    ]
