# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-10 09:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0016_auto_20190510_1652'),
    ]

    operations = [
        migrations.AlterField(
            model_name='section',
            name='group_name',
            field=models.CharField(blank=True, help_text='\u5982\u8bfe\u4ef6\u524d\u4e0d\u9700\u663e\u793a\uff0c\u5219\u4e0d\u7528\u586b\u5199', max_length=180, null=True, verbose_name='\u7ec4\u540d'),
        ),
    ]
