{% extends 'bee_django_course_simple/base.html' %}

{% block content %}
    <div>
        {{ video.file_name }}
    </div>

    <div align="center" class="embed-responsive embed-responsive-16by9">
        <video width='320' height='240' controls id="video_{{ video.id }}" class="embed-responsive-item">
            <source src="{{ url }}" type="video/mp4">
            你的浏览器不支持video标签.
        </video>
    </div>

    <div>
        {{ video.content | safe }}
    </div>
{% endblock content %}