# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-20 12:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0020_auto_20190515_1427'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='auto_pass',
            field=models.BooleanField(default=False, verbose_name='\u81ea\u52a8\u901a\u8fc7'),
        ),
        migrations.AddField(
            model_name='section',
            name='type',
            field=models.IntegerField(choices=[(1, '\u666e\u901a\u8bfe\u4ef6'), (2, '\u9884\u5907\u8bfe\u4ef6')], default=1, verbose_name='\u8bfe\u4ef6\u7c7b\u578b'),
        ),
    ]
