{% extends "bee_django_course_simple/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}
    <h4>


        <a href="{% url 'bee_django_course_simple:course_detail'  pk=part.section.course.id %}">{{ part.section.course.title }}</a>
        ->
        <a href="{% url 'bee_django_course_simple:section_detail'  pk=part.section.id %}">课件【{{ part.section.title }}】详情 </a>
        ->
        <a href="{% url 'bee_django_course_simple:part_detail'  pk=part.id %}">小节【{{ part.title }}】详情 </a>
        ->
        添加/修改选择题

    </h4>
    <form method="post">
        {% csrf_token %}

        {% bootstrap_form form %}
        {% bootstrap_button '下一步' %}
    </form>
{% endblock %}

{% block scripts %}
    <script type="text/javascript">
        $(document).ready(function () {

            {#            var E = window.wangEditor;#}
            {#            var editor = new E('id_info');#}
            {#            editor.config.menus = [#}
            {#                'source',#}
            {#                '|',#}
            {#                'bold',#}
            {#                'underline',#}
            {#                'italic',#}
            {#                'strikethrough',#}
            {#                'eraser',#}
            {#                'forecolor',#}
            {#                'bgcolor',#}
            {#                '|',#}
            {#                'quote',#}
            {#                'fontfamily',#}
            {#                'fontsize',#}
            {#                'head',#}
            {#                'unorderlist',#}
            {#                'orderlist',#}
            {#                'alignleft',#}
            {#                'aligncenter',#}
            {#                'alignright',#}
            {#                '|',#}
            {#                'link',#}
            {#                'unlink',#}
            {#                'table',#}
            {#                'emotion',#}
            {#                '|',#}
            {#                'img',#}
            {#                'video',#}
            {#                'location',#}
            {#                'insertcode',#}
            {#            ];#}
            {##}
            {#            editor.config.uploadImgFileName = 'image';#}
            {#            editor.config.uploadImgUrl = "{% url 'bee_django_course_simple:upload_image' %}";#}
            {#            editor.create();#}
            {##}
            {#            window.editor = editor;#}
        });
    </script>
{% endblock %}