# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-10 08:52
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0015_section_pre_title'),
    ]

    operations = [
        migrations.AddField(
            model_name='part',
            name='pre_title',
            field=models.CharField(max_length=180, null=True, verbose_name='\u6807\u9898\u524d\u7f00'),
        ),
        migrations.AddField(
            model_name='section',
            name='group_name',
            field=models.CharField(help_text='\u5982\u8bfe\u4ef6\u524d\u4e0d\u9700\u663e\u793a\uff0c\u5219\u4e0d\u7528\u586b\u5199', max_length=180, null=True, verbose_name='\u7ec4\u540d'),
        ),
        migrations.AlterField(
            model_name='course',
            name='title',
            field=models.CharField(max_length=180, verbose_name='\u8bfe\u7a0b\u6807\u9898'),
        ),
        migrations.AlterField(
            model_name='section',
            name='pre_title',
            field=models.CharField(max_length=180, null=True, verbose_name='\u6807\u9898\u524d\u7f00'),
        ),
        migrations.AlterField(
            model_name='section',
            name='title',
            field=models.CharField(max_length=180, verbose_name='\u8bfe\u4ef6\u6807\u9898'),
        ),
    ]
