# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-10 05:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0014_course_is_auto_open'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='pre_title',
            field=models.CharField(max_length=180, null=True, verbose_name='\u540d\u5b57\u524d\u7f00'),
        ),
    ]
