{% extends "bee_django_course_simple/base.html" %}
{% load bee_django_course_simple_filter %}
{% load bootstrap3 %}
{% block content %}

    <h4>{{ user_section.section.title }}</h4>

{% endblock content %}