/* 编辑器边框颜色 */
/* 菜单颜色、上边框颜色 */
/* 菜单选中状态的颜色 */
/* input focus 时的颜色 */
/* 按钮颜色 */
/* tab selected 状态下的颜色 */
.wangEditor-container {
  position: relative;
  background-color: #fff;
  border: 1px solid #ccc;
  z-index: 1;
  width: 100%;
}
.wangEditor-container a:focus,
.wangEditor-container button:focus {
  outline: none;
}
.wangEditor-container,
.wangEditor-container * {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
  line-height: 1;
}
.wangEditor-container img {
  border: none;
}
.wangEditor-container .clearfix:after {
  content: '';
  display: table;
  clear: both;
}
.wangEditor-container .clearfix {
  *zoom: 1;
}
.wangEditor-container textarea {
  border: none;
}
.wangEditor-container textarea:focus {
  outline: none;
}
.wangEditor-container .height-tip {
  position: absolute;
  width: 3px;
  background-color: #ccc;
  left: 0;
  transition: top .2s;
}
.wangEditor-container .txt-toolbar {
  position: absolute;
  background-color: #fff;
  padding: 3px 5px;
  border-top: 2px solid #666;
  box-shadow: 1px 3px 3px #999;
  border-left: 1px\9 solid\9 #ccc\9;
  border-bottom: 1px\9 solid\9 #999\9;
  border-right: 1px\9 solid\9 #999\9;
}
.wangEditor-container .txt-toolbar .tip-triangle {
  display: block;
  position: absolute;
  width: 0;
  height: 0;
  border: 5px solid;
  border-color: transparent transparent #666 transparent;
  top: -12px;
  left: 50%;
  margin-left: -5px;
}
.wangEditor-container .txt-toolbar a {
  color: #666;
  display: inline-block;
  margin: 0 3px;
  padding: 5px;
  text-decoration: none;
  border-radius: 3px;
}
.wangEditor-container .txt-toolbar a:hover {
  background-color: #f1f1f1;
}
.wangEditor-container .img-drag-point {
  display: block;
  position: absolute;
  width: 12px;
  height: 12px;
  border-radius: 50%;
  cursor: se-resize;
  background-color: #666;
  margin-left: -6px;
  margin-top: -6px;
  box-shadow: 1px 1px 5px #999;
}
.wangEditor-container .wangEditor-upload-progress {
  position: absolute;
  height: 1px;
  background: #1e88e5;
  width: 0;
  display: none;
  -webkit-transition: width .5s;
  -o-transition: width .5s;
  transition: width .5s;
}
.wangEditor-fullscreen {
  position: fixed;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
}
.wangEditor-container .code-textarea {
  resize: none;
  width: 100%;
  font-size: 14px;
  line-height: 1.5;
  font-family: 'Verdana';
  color: #333;
  padding: 0 15px 0 15px;
}
.wangEditor-menu-container {
  width: 100%;
  border-bottom: 1px solid #f1f1f1;
  background-color: #fff;
}
.wangEditor-menu-container a {
  text-decoration: none;
}
.wangEditor-menu-container .menu-group {
  float: left;
  padding: 0 8px;
  border-right: 1px solid #f1f1f1;
}
.wangEditor-menu-container .menu-item {
  float: left;
  position: relative;
  text-align: center;
  height: 31px;
  width: 35px;
}
.wangEditor-menu-container .menu-item:hover {
  background-color: #f1f1f1;
}
.wangEditor-menu-container .menu-item a {
  display: block;
  text-align: center;
  color: #666;
  width: 100%;
  padding: 8px 0;
  font-size: 0.9em;
}
.wangEditor-menu-container .menu-item .selected {
  color: #1e88e5;
}
.wangEditor-menu-container .menu-item .active {
  background-color: #f1f1f1;
}
.wangEditor-menu-container .menu-item .disable {
  opacity: 0.5;
  filter: alpha(opacity=50);
}
.wangEditor-menu-container .menu-tip {
  display: block;
  position: absolute;
  z-index: 20;
  width: 60px;
  text-align: center;
  background-color: #666;
  color: #fff;
  padding: 7px 0;
  font-size: 12px;
  top: 100%;
  left: 50%;
  margin-left: -30px;
  border-radius: 2px;
  box-shadow: 1px 1px 5px #999;
  display: none;
  /*// 小三角
        .tip-triangle {
            display: block;
            position: absolute;
            width: 0;
            height: 0;
            border:5px solid;
            border-color: transparent transparent @fore-color transparent;
            top: -10px;
            left: 50%;
            margin-left: -5px;
        }*/
}
.wangEditor-menu-container .menu-tip-40 {
  width: 40px;
  margin-left: -20px;
}
.wangEditor-menu-container .menu-tip-50 {
  width: 50px;
  margin-left: -25px;
}
.wangEditor-menu-shadow {
  /*border-bottom-width: 0;*/
  border-bottom: 1px\9 solid\9 #f1f1f1\9;
  box-shadow: 0 1px 3px #999;
}
.wangEditor-container .wangEditor-txt {
  width: 100%;
  text-align: left;
  padding: 15px;
  padding-top: 0;
  margin-top: 5px;
  overflow-y: auto;
}
.wangEditor-container .wangEditor-txt p,
.wangEditor-container .wangEditor-txt h1,
.wangEditor-container .wangEditor-txt h2,
.wangEditor-container .wangEditor-txt h3,
.wangEditor-container .wangEditor-txt h4,
.wangEditor-container .wangEditor-txt h5 {
  margin: 10px 0;
  line-height: 1.8;
}
.wangEditor-container .wangEditor-txt p *,
.wangEditor-container .wangEditor-txt h1 *,
.wangEditor-container .wangEditor-txt h2 *,
.wangEditor-container .wangEditor-txt h3 *,
.wangEditor-container .wangEditor-txt h4 *,
.wangEditor-container .wangEditor-txt h5 * {
  line-height: 1.8;
}
.wangEditor-container .wangEditor-txt ul,
.wangEditor-container .wangEditor-txt ol {
  padding-left: 20px;
}
.wangEditor-container .wangEditor-txt img {
  cursor: pointer;
}
.wangEditor-container .wangEditor-txt img.clicked {
  box-shadow: 1px 1px 10px #999;
}
.wangEditor-container .wangEditor-txt table.clicked {
  box-shadow: 1px 1px 10px #999;
}
.wangEditor-container .wangEditor-txt pre code {
  line-height: 1.5;
}
.wangEditor-container .wangEditor-txt:focus {
  outline: none;
}
.wangEditor-container .wangEditor-txt blockquote {
  display: block;
  border-left: 8px solid #d0e5f2;
  padding: 5px 10px;
  margin: 10px 0;
  line-height: 1.4;
  font-size: 100%;
  background-color: #f1f1f1;
}
.wangEditor-container .wangEditor-txt table {
  border: none;
  border-collapse: collapse;
}
.wangEditor-container .wangEditor-txt table td,
.wangEditor-container .wangEditor-txt table th {
  border: 1px solid #999;
  padding: 3px 5px;
  min-width: 50px;
  height: 20px;
}
.wangEditor-container .wangEditor-txt pre {
  border: 1px solid #ccc;
  background-color: #f8f8f8;
  padding: 10px;
  margin: 5px 0px;
  font-size: 0.8em;
  border-radius: 3px;
}
.wangEditor-drop-list {
  display: none;
  position: absolute;
  background-color: #fff;
  overflow: hidden;
  z-index: 10;
  transition: height .7s;
  border-top: 1px solid #f1f1f1;
  box-shadow: 1px 3px 3px #999;
  border-left: 1px\9 solid\9 #ccc\9;
  border-bottom: 1px\9 solid\9 #999\9;
  border-right: 1px\9 solid\9 #999\9;
}
.wangEditor-drop-list a {
  text-decoration: none;
  display: block;
  color: #666;
  padding: 3px 5px;
}
.wangEditor-drop-list a:hover {
  background-color: #f1f1f1;
}
.wangEditor-drop-panel,
.txt-toolbar {
  display: none;
  position: absolute;
  padding: 10px;
  font-size: 14px;
  /*border: 1px\9 solid\9 #cccccc\9;*/
  background-color: #fff;
  z-index: 10;
  border-top: 2px solid #666;
  box-shadow: 1px 3px 3px #999;
  border-left: 1px\9 solid\9 #ccc\9;
  border-bottom: 1px\9 solid\9 #999\9;
  border-right: 1px\9 solid\9 #999\9;
}
.wangEditor-drop-panel .tip-triangle,
.txt-toolbar .tip-triangle {
  display: block;
  position: absolute;
  width: 0;
  height: 0;
  border: 5px solid;
  border-color: transparent transparent #666 transparent;
  top: -12px;
  left: 50%;
  margin-left: -5px;
}
.wangEditor-drop-panel a,
.txt-toolbar a {
  text-decoration: none;
}
.wangEditor-drop-panel input[type=text],
.txt-toolbar input[type=text] {
  border: none;
  border-bottom: 1px solid #ccc;
  font-size: 14px;
  height: 20px;
  color: #333;
  padding: 3px 0;
}
.wangEditor-drop-panel input[type=text]:focus,
.txt-toolbar input[type=text]:focus {
  outline: none;
  border-bottom: 2px solid #1e88e5;
}
.wangEditor-drop-panel input[type=text].block,
.txt-toolbar input[type=text].block {
  display: block;
  width: 100%;
}
.wangEditor-drop-panel textarea,
.txt-toolbar textarea {
  border: 1px solid #ccc;
}
.wangEditor-drop-panel textarea:focus,
.txt-toolbar textarea:focus {
  outline: none;
  border-color: #1e88e5;
}
.wangEditor-drop-panel button,
.txt-toolbar button {
  font-size: 14px;
  color: #1e88e5;
  border: none;
  padding: 10px;
  background-color: #fff;
  cursor: pointer;
  border-radius: 3px;
}
.wangEditor-drop-panel button:hover,
.txt-toolbar button:hover {
  background-color: #f1f1f1;
}
.wangEditor-drop-panel button:focus,
.txt-toolbar button:focus {
  outline: none;
}
.wangEditor-drop-panel button.right,
.txt-toolbar button.right {
  float: right;
  margin-left: 10px;
}
.wangEditor-drop-panel button.gray,
.txt-toolbar button.gray {
  color: #999;
}
.wangEditor-drop-panel button.link,
.txt-toolbar button.link {
  padding: 5px 10px;
}
.wangEditor-drop-panel button.link:hover,
.txt-toolbar button.link:hover {
  background-color: #fff;
  text-decoration: underline;
}
.wangEditor-drop-panel .color-item,
.txt-toolbar .color-item {
  display: block;
  float: left;
  width: 25px;
  height: 25px;
  text-align: center;
  padding: 2px;
  border-radius: 2px;
  text-decoration: underline;
}
.wangEditor-drop-panel .color-item:hover,
.txt-toolbar .color-item:hover {
  background-color: #f1f1f1;
}
.wangEditor-drop-panel .list-menu-item,
.txt-toolbar .list-menu-item {
  display: block;
  float: left;
  color: #333;
  padding: 5px 5px;
  border-radius: 2px;
}
.wangEditor-drop-panel .list-menu-item:hover,
.txt-toolbar .list-menu-item:hover {
  background-color: #f1f1f1;
}
.wangEditor-drop-panel table.choose-table,
.txt-toolbar table.choose-table {
  border: none;
  border-collapse: collapse;
}
.wangEditor-drop-panel table.choose-table td,
.txt-toolbar table.choose-table td {
  border: 1px solid #ccc;
  width: 16px;
  height: 12px;
}
.wangEditor-drop-panel table.choose-table td.active,
.txt-toolbar table.choose-table td.active {
  background-color: #ccc;
  opacity: .5;
  filter: alpha(opacity=50);
}
.wangEditor-drop-panel .panel-tab .tab-container,
.txt-toolbar .panel-tab .tab-container {
  margin-bottom: 5px;
}
.wangEditor-drop-panel .panel-tab .tab-container a,
.txt-toolbar .panel-tab .tab-container a {
  display: inline-block;
  color: #999;
  text-align: center;
  margin: 0 5px;
  padding: 5px 5px;
}
.wangEditor-drop-panel .panel-tab .tab-container a.selected,
.txt-toolbar .panel-tab .tab-container a.selected {
  color: #1e88e5;
  border-bottom: 2px solid #1e88e5;
}
.wangEditor-drop-panel .panel-tab .content-container .content,
.txt-toolbar .panel-tab .content-container .content {
  display: none;
}
.wangEditor-drop-panel .panel-tab .content-container .content a,
.txt-toolbar .panel-tab .content-container .content a {
  display: inline-block;
  margin: 2px;
  padding: 2px;
  border-radius: 2px;
}
.wangEditor-drop-panel .panel-tab .content-container .content a:hover,
.txt-toolbar .panel-tab .content-container .content a:hover {
  background-color: #f1f1f1;
}
.wangEditor-drop-panel .panel-tab .content-container .selected,
.txt-toolbar .panel-tab .content-container .selected {
  display: block;
}
.wangEditor-drop-panel .panel-tab .emotion-content-container,
.txt-toolbar .panel-tab .emotion-content-container {
  height: 200px;
  overflow-y: auto;
}
.wangEditor-drop-panel .upload-icon-container,
.txt-toolbar .upload-icon-container {
  color: #ccc;
  text-align: center;
  margin: 20px 20px 15px 20px !important;
  padding: 5px !important;
  font-size: 65px;
  cursor: pointer;
  border: 2px dotted #f1f1f1;
  display: block !important;
}
.wangEditor-drop-panel .upload-icon-container:hover,
.txt-toolbar .upload-icon-container:hover {
  color: #666;
  border-color: #ccc;
}
.wangEditor-modal {
  position: absolute;
  top: 50%;
  left: 50%;
  background-color: #fff;
  border-top: 1px solid #f1f1f1;
  box-shadow: 1px 3px 3px #999;
  border-top: 1px\9 solid\9 #ccc\9;
  border-left: 1px\9 solid\9 #ccc\9;
  border-bottom: 1px\9 solid\9 #999\9;
  border-right: 1px\9 solid\9 #999\9;
}
.wangEditor-modal .wangEditor-modal-close {
  position: absolute;
  top: 0;
  right: 0;
  margin-top: -25px;
  margin-right: -25px;
  font-size: 1.5em;
  color: #666;
  cursor: pointer;
}
@font-face {
  font-family: 'icomoon';
  src: url('../fonts/icomoon.eot?-qdfu1s');
  src: url('../fonts/icomoon.eot?#iefix-qdfu1s') format('embedded-opentype'), url('../fonts/icomoon.ttf?-qdfu1s') format('truetype'), url('../fonts/icomoon.woff?-qdfu1s') format('woff'), url('../fonts/icomoon.svg?-qdfu1s#icomoon') format('svg');
  font-weight: normal;
  font-style: normal;
}
[class^="wangeditor-menu-img-"],
[class*=" wangeditor-menu-img-"] {
  font-family: 'icomoon';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.wangeditor-menu-img-link:before {
  content: "\e800";
}
.wangeditor-menu-img-unlink:before {
  content: "\e801";
}
.wangeditor-menu-img-code:before {
  content: "\e802";
}
.wangeditor-menu-img-cancel:before {
  content: "\e803";
}
.wangeditor-menu-img-terminal:before {
  content: "\e804";
}
.wangeditor-menu-img-angle-down:before {
  content: "\e805";
}
.wangeditor-menu-img-font:before {
  content: "\e806";
}
.wangeditor-menu-img-bold:before {
  content: "\e807";
}
.wangeditor-menu-img-italic:before {
  content: "\e808";
}
.wangeditor-menu-img-header:before {
  content: "\e809";
}
.wangeditor-menu-img-align-left:before {
  content: "\e80a";
}
.wangeditor-menu-img-align-center:before {
  content: "\e80b";
}
.wangeditor-menu-img-align-right:before {
  content: "\e80c";
}
.wangeditor-menu-img-list-bullet:before {
  content: "\e80d";
}
.wangeditor-menu-img-indent-left:before {
  content: "\e80e";
}
.wangeditor-menu-img-indent-right:before {
  content: "\e80f";
}
.wangeditor-menu-img-list-numbered:before {
  content: "\e810";
}
.wangeditor-menu-img-underline:before {
  content: "\e811";
}
.wangeditor-menu-img-table:before {
  content: "\e812";
}
.wangeditor-menu-img-eraser:before {
  content: "\e813";
}
.wangeditor-menu-img-text-height:before {
  content: "\e814";
}
.wangeditor-menu-img-brush:before {
  content: "\e815";
}
.wangeditor-menu-img-pencil:before {
  content: "\e816";
}
.wangeditor-menu-img-minus:before {
  content: "\e817";
}
.wangeditor-menu-img-picture:before {
  content: "\e818";
}
.wangeditor-menu-img-file-image:before {
  content: "\e819";
}
.wangeditor-menu-img-cw:before {
  content: "\e81a";
}
.wangeditor-menu-img-ccw:before {
  content: "\e81b";
}
.wangeditor-menu-img-music:before {
  content: "\e911";
}
.wangeditor-menu-img-play:before {
  content: "\e912";
}
.wangeditor-menu-img-location:before {
  content: "\e947";
}
.wangeditor-menu-img-happy:before {
  content: "\e9df";
}
.wangeditor-menu-img-sigma:before {
  content: "\ea67";
}
.wangeditor-menu-img-enlarge2:before {
  content: "\e98b";
}
.wangeditor-menu-img-shrink2:before {
  content: "\e98c";
}
.wangeditor-menu-img-newspaper:before {
  content: "\e904";
}
.wangeditor-menu-img-camera:before {
  content: "\e90f";
}
.wangeditor-menu-img-video-camera:before {
  content: "\e914";
}
.wangeditor-menu-img-file-zip:before {
  content: "\e92b";
}
.wangeditor-menu-img-stack:before {
  content: "\e92e";
}
.wangeditor-menu-img-credit-card:before {
  content: "\e93f";
}
.wangeditor-menu-img-address-book:before {
  content: "\e944";
}
.wangeditor-menu-img-envelop:before {
  content: "\e945";
}
.wangeditor-menu-img-drawer:before {
  content: "\e95c";
}
.wangeditor-menu-img-download:before {
  content: "\e960";
}
.wangeditor-menu-img-upload:before {
  content: "\e961";
}
.wangeditor-menu-img-lock:before {
  content: "\e98f";
}
.wangeditor-menu-img-unlocked:before {
  content: "\e990";
}
.wangeditor-menu-img-wrench:before {
  content: "\e991";
}
.wangeditor-menu-img-eye:before {
  content: "\e9ce";
}
.wangeditor-menu-img-eye-blocked:before {
  content: "\e9d1";
}
.wangeditor-menu-img-command:before {
  content: "\ea4e";
}
.wangeditor-menu-img-font2:before {
  content: "\ea5c";
}
.wangeditor-menu-img-libreoffice:before {
  content: "\eade";
}
.wangeditor-menu-img-quotes-left:before {
  content: "\e977";
}
.wangeditor-menu-img-strikethrough:before {
  content: "\ea65";
}
.wangeditor-menu-img-desktop:before {
  content: "\f108";
}
.wangeditor-menu-img-tablet:before {
  content: "\f10a";
}
.wangeditor-menu-img-search-plus:before {
  content: "\f00e";
}
.wangeditor-menu-img-search-minus:before {
  content: "\f010";
}
.wangeditor-menu-img-trash-o:before {
  content: "\f014";
}
.wangeditor-menu-img-align-justify:before {
  content: "\f039";
}
.wangeditor-menu-img-arrows-v:before {
  content: "\f07d";
}
.wangeditor-menu-img-sigma2:before {
  content: "\ea68";
}
.wangeditor-menu-img-omega:before {
  content: "\e900";
}
.wangeditor-menu-img-cancel-circle:before {
  content: "\e901";
}
.hljs {
  display: block;
  overflow-x: auto;
  padding: 0.5em;
  color: #333;
  background: #f8f8f8;
  -webkit-text-size-adjust: none;
}
.hljs-comment,
.diff .hljs-header {
  color: #998;
  font-style: italic;
}
.hljs-keyword,
.css .rule .hljs-keyword,
.hljs-winutils,
.nginx .hljs-title,
.hljs-subst,
.hljs-request,
.hljs-status {
  color: #333;
  font-weight: bold;
}
.hljs-number,
.hljs-hexcolor,
.ruby .hljs-constant {
  color: #008080;
}
.hljs-string,
.hljs-tag .hljs-value,
.hljs-doctag,
.tex .hljs-formula {
  color: #d14;
}
.hljs-title,
.hljs-id,
.scss .hljs-preprocessor {
  color: #900;
  font-weight: bold;
}
.hljs-list .hljs-keyword,
.hljs-subst {
  font-weight: normal;
}
.hljs-class .hljs-title,
.hljs-type,
.vhdl .hljs-literal,
.tex .hljs-command {
  color: #458;
  font-weight: bold;
}
.hljs-tag,
.hljs-tag .hljs-title,
.hljs-rule .hljs-property,
.django .hljs-tag .hljs-keyword {
  color: #000080;
  font-weight: normal;
}
.hljs-attribute,
.hljs-variable,
.lisp .hljs-body,
.hljs-name {
  color: #008080;
}
.hljs-regexp {
  color: #009926;
}
.hljs-symbol,
.ruby .hljs-symbol .hljs-string,
.lisp .hljs-keyword,
.clojure .hljs-keyword,
.scheme .hljs-keyword,
.tex .hljs-special,
.hljs-prompt {
  color: #990073;
}
.hljs-built_in {
  color: #0086b3;
}
.hljs-preprocessor,
.hljs-pragma,
.hljs-pi,
.hljs-doctype,
.hljs-shebang,
.hljs-cdata {
  color: #999;
  font-weight: bold;
}
.hljs-deletion {
  background: #fdd;
}
.hljs-addition {
  background: #dfd;
}
.diff .hljs-change {
  background: #0086b3;
}
.hljs-chunk {
  color: #aaa;
}
