# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-23 07:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0013_auto_20190421_1848'),
    ]

    operations = [
        migrations.AddField(
            model_name='course',
            name='is_auto_open',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u81ea\u52a8\u5f00\u542f'),
        ),
    ]
