<script type="text/javascript">
    window.section_pass_alert = '课件已通过';
    window.part_pass_alert = '小节已通过';
    window.question_all_pass = '恭喜你，全部答对了！';
    window.question_1_pass = '你战胜了50%的用户';
    window.question_2_pass = '你战胜了80%的用户';
    window.question_no_pass = '';
</script>