# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-18 05:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0005_userimage'),
    ]

    operations = [
        migrations.AddField(
            model_name='userimage',
            name='model_id',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='userimage',
            name='model_name',
            field=models.CharField(max_length=180, null=True, verbose_name='model\u540d'),
        ),
        migrations.AlterField(
            model_name='userimage',
            name='image',
            field=models.ImageField(upload_to='bee_django_course_simple/video_image/%Y/%m/%d', verbose_name='\u56fe\u7247'),
        ),
    ]
