# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-16 08:13
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Course',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u8bfe\u7a0b\u540d\u5b57')),
                ('subtitle', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u8bfe\u7a0b\u526f\u6807\u9898')),
                ('level', models.IntegerField(blank=True, default=0, verbose_name='\u8bfe\u7a0b\u7684level')),
                ('is_del', models.IntegerField(default=0)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'ordering': ['-id'],
                'db_table': 'bee_django_course_simple_course',
                'verbose_name': 'course\u8bfe\u7a0b',
            },
        ),
        migrations.CreateModel(
            name='Option',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u9009\u9879')),
                ('number', models.IntegerField(default=0, verbose_name='\u987a\u5e8f')),
                ('is_correct', models.BooleanField(default=False, verbose_name='\u662f\u5426\u6b63\u786e\u7b54\u6848')),
            ],
            options={
                'ordering': ['pk'],
                'db_table': 'bee_django_course_simple_option',
            },
        ),
        migrations.CreateModel(
            name='Part',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u6807\u9898')),
                ('number', models.IntegerField(default=1, verbose_name='\u6392\u5e8f')),
                ('type', models.IntegerField(default=1, verbose_name='\u7c7b\u578b')),
                ('has_answer', models.BooleanField(default=False, verbose_name='\u662f\u5426\u6709\u6b63\u786e\u7b54\u6848')),
            ],
            options={
                'ordering': ['-id'],
                'db_table': 'bee_django_course_simple_part',
                'verbose_name': '\u5c0f\u8282',
            },
        ),
        migrations.CreateModel(
            name='Question',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('number', models.IntegerField(default=1, verbose_name='\u6392\u5e8f')),
                ('title', models.CharField(max_length=180, null=True, verbose_name='\u95ee\u9898')),
                ('tip_wrong', models.TextField(null=True, verbose_name='\u9519\u8bef\u65f6\u63d0\u793a\u8bcd')),
                ('tip_correct', models.TextField(null=True, verbose_name='\u6b63\u786e\u65f6\u63d0\u793a\u8bcd')),
                ('part', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Part', verbose_name='\u5c0f\u8282')),
            ],
            options={
                'ordering': ['pk'],
                'db_table': 'bee_django_course_simple_question',
            },
        ),
        migrations.CreateModel(
            name='Section',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u8bfe\u4ef6\u540d\u5b57')),
                ('number', models.IntegerField(default=1, verbose_name='\u6392\u5e8f')),
                ('info', models.TextField(blank=True, null=True, verbose_name='\u4ecb\u7ecd')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('course', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Course', verbose_name='\u5c5e\u4e8e\u7684\u8bfe\u7a0b')),
            ],
            options={
                'ordering': ['-id'],
                'db_table': 'bee_django_course_simple_section',
                'verbose_name': 'course\u8bfe\u4ef6',
            },
        ),
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('number', models.IntegerField(default=1, verbose_name='\u6392\u5e8f')),
                ('content', models.TextField(verbose_name='\u5185\u5bb9')),
                ('part', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Part', verbose_name='\u5c0f\u8282')),
                ('url', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Question', verbose_name='\u89c6\u9891\u5730\u5740')),
            ],
            options={
                'ordering': ['pk'],
                'db_table': 'bee_django_course_simple_video',
            },
        ),
        migrations.AddField(
            model_name='part',
            name='section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Section', verbose_name='\u5c5e\u4e8e\u7684\u8bfe\u4ef6'),
        ),
        migrations.AddField(
            model_name='option',
            name='question',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Question', verbose_name='\u95ee\u9898'),
        ),
    ]
