
{% extends "bee_django_course_simple/user_base.html" %}
{% load bee_django_course_simple_filter %}
{% load bootstrap3 %}

{% block content %}
    。。。。

{% endblock content %}

{% block scripts %}
{% endblock scripts %}