# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-15 06:27
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0019_auto_20190513_1315'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userquestion',
            name='answer_option_id',
        ),
        migrations.AddField(
            model_name='userquestion',
            name='answer_option',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Option'),
        ),
    ]
