# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-21 09:52
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0008_usersection_started_at'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='course',
            options={'ordering': ['-id'], 'permissions': [('can_manage_course', '\u53ef\u4ee5\u8fdb\u5165\u8bfe\u7a0b\u7ba1\u7406\u9875'), ('view_all_courses', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u8bfe\u7a0b')]},
        ),
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ['number'], 'permissions': (('view_question', '\u53ef\u4ee5\u67e5\u770b\u95ee\u9898\u5217\u8868'),)},
        ),
        migrations.AlterModelOptions(
            name='section',
            options={'ordering': ['number'], 'permissions': [('view_all_sections', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u8bfe\u4ef6')]},
        ),
        migrations.AlterModelOptions(
            name='usercourse',
            options={'ordering': ['-created_at'], 'permissions': [('assign_user_course', '\u80fd\u7ed9\u5b66\u751f\u5206\u914d\u8bfe\u7a0b')]},
        ),
        migrations.AlterModelOptions(
            name='usersection',
            options={'ordering': ['section__number'], 'permissions': [('pass_ucs', '\u80fd\u901a\u8fc7\u5b66\u751f\u8bfe\u4ef6'), ('close_ucs', '\u80fd\u5173\u95ed\u5b66\u751f\u8bfe\u4ef6'), ('open_ucs', '\u80fd\u5f00\u542f\u5b66\u751f\u8bfe\u4ef6')]},
        ),
    ]
