# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-13 05:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0017_auto_20190510_1710'),
    ]

    operations = [
        migrations.AddField(
            model_name='part',
            name='extra_title',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u989d\u5916\u6807\u9898'),
        ),
        migrations.AddField(
            model_name='section',
            name='extra_title',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u989d\u5916\u6807\u9898'),
        ),
        migrations.AlterField(
            model_name='part',
            name='pre_title',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6807\u9898\u524d\u7f00'),
        ),
        migrations.AlterField(
            model_name='section',
            name='pre_title',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6807\u9898\u524d\u7f00'),
        ),
    ]
