# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-21 10:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import smart_selects.db_fields


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0011_question_course'),
    ]

    operations = [
        migrations.AlterField(
            model_name='question',
            name='course',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Course', verbose_name='\u8bfe\u7a0b'),
        ),
        migrations.AlterField(
            model_name='question',
            name='part',
            field=smart_selects.db_fields.ChainedForeignKey(auto_choose=True, blank=True, chained_field='section', chained_model_field='section', null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Part', verbose_name='\u5c0f\u8282'),
        ),
        migrations.AlterField(
            model_name='question',
            name='section',
            field=smart_selects.db_fields.ChainedForeignKey(auto_choose=True, blank=True, chained_field='course', chained_model_field='course', null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Section', verbose_name='\u8bfe\u4ef6'),
        ),
    ]
