# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-24 11:34
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0023_auto_20190524_1705'),
    ]

    operations = [
        migrations.AddField(
            model_name='userpart',
            name='question_correct_count',
            field=models.IntegerField(default=0, verbose_name='\u7b54\u5bf9\u4e86\u51e0\u9053\u9898'),
        ),
    ]
