# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-24 09:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0022_part_image'),
    ]

    operations = [
        migrations.CreateModel(
            name='QuestionPrize',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('correct_count', models.IntegerField(unique=True, verbose_name='\u7b54\u5bf9\u95ee\u9898\u7684\u6570\u91cf')),
                ('coin', models.IntegerField(verbose_name='\u5956\u52b1M\u5e01')),
            ],
            options={
                'ordering': ['correct_count'],
                'db_table': 'bee_django_course_simple_question_prize',
            },
        ),
        migrations.AddField(
            model_name='userpart',
            name='prize_coin',
            field=models.IntegerField(default=0, verbose_name='\u5956\u52b1\u7684m\u5e01'),
        ),
    ]
