# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-20 12:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0021_auto_20190520_2014'),
    ]

    operations = [
        migrations.AddField(
            model_name='part',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='bee_django_course_simple/part_image', verbose_name='\u914d\u56fe'),
        ),
    ]
