# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-21 10:26
from __future__ import unicode_literals

from django.db import migrations
import django.db.models.deletion
import smart_selects.db_fields


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0009_auto_20190421_1752'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='section',
            field=smart_selects.db_fields.ChainedForeignKey(auto_choose=True, blank=True, chained_field='part', chained_model_field='part', null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Section', verbose_name='\u8bfe\u4ef6'),
        ),
    ]
