# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-21 10:48
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0012_auto_20190421_1846'),
    ]

    operations = [
        migrations.AlterField(
            model_name='question',
            name='course',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course_simple.Course', verbose_name='\u8bfe\u7a0b'),
        ),
    ]
