# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-13 05:15
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0018_auto_20190513_1312'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='part',
            name='pre_title',
        ),
        migrations.RemoveField(
            model_name='section',
            name='pre_title',
        ),
    ]
