<style>
    .nav {
        background-color: #4B6788;
        height: 40px;
        color: #ffffff;
        line-height: 40px;
        padding: 0 10px;
    }

    .nav a {
        color: #ffffff;
    }
</style>

<div class="nav">
    <a href="/">首页 |</a>
    <a href="{% url 'bee_django_course_simple:course_list' %}">课程管理</a> |
    <a href="{% url 'bee_django_course_simple:user_section_list' 1 0 %}">1的课表（后台测试）</a> |
    <a href="{% url 'bee_django_course_simple:custom_user_section_redirect' page_type='detail' user_id=1 section_type=1 %}">1的普通课表（前台测试）</a>
    |
    <a href="{% url 'bee_django_course_simple:custom_user_section_redirect' page_type='list' user_id=1 section_type=2 %}">1的预备课（前台测试）</a>
    |
    <a href="{% url 'bee_django_course_simple:question_list' %}">答题报表</a> |
    <a href="http://note.youdao.com/noteshare?id=2afdcb822f23e97e3903743de812232d" target="_blank">帮助文档</a> |


</div>
{% load bootstrap3 %}
{% bootstrap_messages %}