{% extends "bee_django_course_simple/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}
    <h4>

        <a href="{% url 'bee_django_course_simple:course_detail'  pk=section.course.id %}">{{ section.course.title }}</a>
        ->
        <a href="{% url 'bee_django_course_simple:section_detail'  pk=section.id %}">课件【{{ section.title }}】详情 </a>
        ->
        {% if type == 'add' %}添加{% elif type == 'update' %}修改{% endif %}小节
    </h4>
    <form method="post" enctype="multipart/form-data">
        {% csrf_token %}

        {% bootstrap_form form %}
        {% bootstrap_button '保存' name='ok' %}

    </form>
{% endblock %}

{% block scripts %}
    <script type="text/javascript">
        $(document).ready(function () {

        });
    </script>
{% endblock %}