<style>
    .user_section_list {
    }

    .user_section {
        margin: 15px auto;

    }
    .user_part{
        margin-left: 10px;
    }

    .section_group_name {
        font-size: 1.5em;
    }

    .section_title {
        font-weight: 900;
    }

    .part_title {

    }
</style>