# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-17 09:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0003_auto_20190416_1737'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='video',
            name='url',
        ),
        migrations.AddField(
            model_name='video',
            name='file_name',
            field=models.CharField(default='', max_length=180, verbose_name='\u89c6\u9891\u6587\u4ef6\u540d'),
            preserve_default=False,
        ),
    ]
