{% verbatim %}


<script type="text/x-template" id="part-template">
    <part-image v-bind:image="part.image"
                v-bind:part_title="part.title" v-bind:extra_title="part.extra_title"
                v-bind:status.sync="user_part.status">

    </part-image>
    <div>
        <div style="border-bottom:1px solid #ccc;padding:10px;margin:10px auto;">
            <div v-if="status === 0">

                <i class="glyphicon glyphicon-play-circle">{{ title }}</i>
            </div>
            <div v-else>
                <a href="#" v-on:click.prevent="toggle_detail_part()">
                    <i class="glyphicon glyphicon-play-circle">{{ title }}</i>
                    <span v-if="status === 2" class="user_part_status">{{ extra_title }} </span>
                </a>
            </div>

        </div>
    </div>


</script>

<script type="text/x-template" id="part-image-template">

    <div>

        <div v-if="status === 0">
            <img src="{{ image }}" alt="">
        </div>
        <div v-else>
            <a href="">
                <img src="{{ image }}" alt="">
            </a>
        </div>

    </div>


</script>
{% endverbatim %}